@@ -43,7 +43,7 @@ from subprocess import Popen
 from qtpy import QtCore, QtWidgets
 from qtpy.QtCore import QModelIndex, QPoint
 from qtpy.QtGui import QPixmap, QIcon, QFont, QFontDatabase
-from qtpy.QtWidgets import QMainWindow, QApplication, QListWidgetItem, QMenu
+from qtpy.QtWidgets import QMainWindow, QListWidgetItem, QMenu
 from qtpy.QtWidgets import QMessageBox
 from .lib.utils import format_colors as fc
 from .constants import FONTS
@@ -60,15 +60,21 @@ from .ux.panel import Panel
 from .ux.swipe import SwipeUX
 from .ux.toolkit import InterfaceToolkit
 from .version import VERSION
-from .lib.check import AndroidDebugBridge, ScrcpyBridge
-
+from .lib.check import AndroidDebugBridge, ScrcpyBridge, \
+    ScrcpyServerNotFoundError
 
 environment = platform.System()
 
 # ============================================================================
 # Load cairo-svg conditionally
 if environment.system() == "Linux":
-    from cairosvg import svg2png  # noqa:
+    try:
+        from cairosvg import svg2png  # noqa:
+        has_cairo = True
+    except Exception as e:
+        print("Failed to load cairo:", e)
+        print("Some features are likely to be disabled")
+        has_cairo = False
 
 
 class InterfaceGuiscrcpy(QMainWindow, Ui_MainWindow):
@@ -425,10 +431,17 @@ class InterfaceGuiscrcpy(QMainWindow, Ui_MainWindow):
         ).hexdigest()[__sha_shift:__sha_shift + 6]
         log(f"Creating desktop shortcut sha: {sha}")
         path_to_image = os.path.join(picture_file_path, identifier + '.png')
-        svg2png(
-            bytestring=desktop_device_shortcut_svg().format(f"#{sha}"),
-            write_to=path_to_image
-        )
+        if has_cairo:
+            svg2png(
+                bytestring=desktop_device_shortcut_svg().format(f"#{sha}"),
+                write_to=path_to_image
+            )
+        else:
+            print("Trying to use Plain SVG as renderer"
+                  " instead of cairo")
+            with open(path_to_image, 'w') as fp:
+                svg_str = desktop_device_shortcut_svg().format(f"#{sha}")
+                fp.write(svg_str)
 
         # go through all args; break when we find guiscrcpy
         for args_i in range(len(sys.argv)):
@@ -914,11 +927,11 @@ class InterfaceGuiscrcpy(QMainWindow, Ui_MainWindow):
         # ====================================================================
         # 3: Check devices
         values_devices_list = self.scan_devices_update_list_view()
-        e = self.check_devices_status_and_select_first_if_only_one(
+        _e = self.check_devices_status_and_select_first_if_only_one(
             values_devices_list)
-        if e is None or isinstance(e, int):
-            return e
-        device_id, more_devices, _stat = e
+        if _e is None or isinstance(_e, int):
+            return _e
+        device_id, more_devices, _stat = _e
         progress = self.progress(progress)
 
         # ====================================================================
@@ -1177,25 +1190,22 @@ def set_scrcpy_server_path(config):
         if not os.path.exists(scrcpy_server_path_env):
             server_path = open_exe_name_dialog(None, 'scrcpy-server')
             if server_path is None:
-                print("ERROR: User did not select path to scrcpy-server")
-                print("Cannot proceed without configured server path")
-                print("Aborting: 1")
-                sys.exit(-1)
+                raise ScrcpyServerNotFoundError(
+                    "User did not select scrcpy server")
             config['scrcpy-server'] = server_path
             os.environ['SCRCPY_SERVER_PATH'] = server_path
     elif (
-        (scrcpy_server_path_env is None) and
-        (isinstance(config.get('scrcpy-server'), str) and
-         not os.path.exists(config.get('scrcpy-server')))
+        (scrcpy_server_path_env is None) and (
+            (isinstance(config.get('scrcpy-server'), str) and
+             not os.path.exists(config.get('scrcpy-server'))) or
+            config.get('scrcpy-server') is None)
     ) and (
         platform.System().system() == 'Windows'
     ):
         server_path = open_exe_name_dialog(None, 'scrcpy-server')
         if server_path is None:
-            print("ERROR: User did not select path to scrcpy-server")
-            print("Cannot proceed without configured server path")
-            print("Aborting: 2")
-            sys.exit(-1)
+            raise ScrcpyServerNotFoundError(
+                "User did not select scrcpy server")
         config['scrcpy-server'] = server_path
         os.environ['SCRCPY_SERVER_PATH'] = server_path
     elif platform.System().system() == "Windows":
@@ -1203,19 +1213,13 @@ def set_scrcpy_server_path(config):
     return config
 
 
-def bootstrap(cfgmgr, theme='Breeze', aot=True, debug__no_scrcpy=False,
+def bootstrap(app, cfgmgr, theme='Breeze', aot=True, debug__no_scrcpy=False,
               hide_wm_frame=True):
     """
     Launch the guiscrcpy window
     :return:
     """
     config = cfgmgr.get_config()
-    # enable High DPI scaling
-    QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
-    # use HIGH DPI icons
-    QApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)
-    # init core
-    app = QtWidgets.QApplication([])
 
     # load fonts
     font_database = QFontDatabase()
